lilypondfiletools.LilyPondFile
==============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile

.. autoclass:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.append
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.count
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.default_paper_size
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.extend
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_comments
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_includes
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_comments
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_includes
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.global_staff_size
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.index
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.insert
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.pop
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.remove
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.reverse
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.sort
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__add__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__contains__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__delitem__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__delslice__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__eq__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__format__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__ge__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__getitem__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__getslice__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__gt__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__iadd__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__illustrate__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__imul__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__iter__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__le__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__len__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__lt__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__mul__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__ne__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__repr__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__reversed__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__rmul__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__setitem__
      ~abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__setslice__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.list <list>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.default_paper_size
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_comments
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_system_includes
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_comments
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.file_initial_user_includes
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.global_staff_size
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__illustrate__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LilyPondFile.LilyPondFile.__setslice__
   :noindex:
